==> nbdkit_1.6.2.orig.tar.gz: nbdkit-1.6.2/common/include/rounding.h <==
/* nbdkit
 * Copyright (C) 2018 Red Hat Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of Red Hat nor the names of its contributors may be
 * used to endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef NBDKIT_ROUNDING_H
#define NBDKIT_ROUNDING_H

#include <assert.h>

#include "ispowerof2.h"

/* Round up i to next multiple of n (n must be a power of 2).
 */
#define ROUND_UP(i, n) ({                          \
      assert (is_power_of_2 (n));                  \
      ((i) + (n) - 1) & -((typeof (i))n);          \
})

/* Round down i to next multiple of n (n must be a power of 2).
 */
#define ROUND_DOWN(i, n) ({                         \
      assert (is_power_of_2 (n));                   \
      (i) & -((typeof (i))(n));                     \
})

/* Return n / d, rounding the result up to the next integer. */
#define DIV_ROUND_UP(n, d) (((n) + (d) - 1) / (d))

#endif /* NBDKIT_ROUNDING_H */

==> nbdkit_1.10.3.orig.tar.gz: nbdkit-1.10.3/common/include/rounding.h <==
/* nbdkit
 * Copyright (C) 2018 Red Hat Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of Red Hat nor the names of its contributors may be
 * used to endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef NBDKIT_ROUNDING_H
#define NBDKIT_ROUNDING_H

#include <assert.h>

#include "ispowerof2.h"

/* Round up i to next multiple of n (n must be a power of 2).
 */
#define ROUND_UP(i, n) ({                          \
      assert (is_power_of_2 (n));                  \
      ((i) + (n) - 1) & -((typeof (i))(n));        \
})

/* Round down i to next multiple of n (n must be a power of 2).
 */
#define ROUND_DOWN(i, n) ({                         \
      assert (is_power_of_2 (n));                   \
      (i) & -((typeof (i))(n));                     \
})

/* Return n / d, rounding the result up to the next integer. */
#define DIV_ROUND_UP(n, d) (((n) + (d) - 1) / (d))

#endif /* NBDKIT_ROUNDING_H */
